fedex.config.FedexConfig

Package fedex :: Module config :: Class FedexConfig |
[hide private]
[frames] | no frames]

# Class FedexConfig

source code

Base configuration class that is used for the different Fedex SOAP calls. These are generally passed to the Fedex request classes as arguments. You may instantiate a FedexConfig object with the minimal `key` and `password` arguments and set the instance variables documented below at a later time if you must.

Instance Methods | [hide private]
__init__(self, key, password, account_number=None, meter_number=None, integrator_id=None, wsdl_path=None, use_test_server=False) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Instance Variables | [hide private]
| key Developer test key.
| password Fedex Web Services password.
| account_number Web Services account number.
| meter_number Web services meter number.
| integrator_id Web services integrator ID.
| use_test_server When True, point to the test server.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, key, password, account_number=None, meter_number=None, integrator_id=None, wsdl_path=None, use_test_server=False) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Parameters: `key` (`str`) - Developer test key. `password` (`str`) - The Fedex-generated password for your Web Systems account. This is generally emailed to you after registration. `account_number` (`str`) - The account number sent to you by Fedex after registering for Web Services. `meter_number` (`str`) - The meter number sent to you by Fedex after registering for Web Services. `integrator_id` (`str`) - The integrator string sent to you by Fedex after registering for Web Services. `wsdl_path` (`str`) - In the event that you want to override the path to your WSDL directory, do so with this argument. `use_test_server` (`bool`) - When this is True, test server WSDLs are used instead of the production server. You will also need to make sure that your FedexConfig object has a production account number, meter number, authentication key, and password. Overrides: object.__init__